@@ -1,4 +1,5 @@
 mod commands;
+mod delete_executor;
 mod error;
 mod markdown;
 mod opts;
@@ -8,6 +9,7 @@ mod scaffold_executor;
 mod template;
 mod template_repository;
 
+use crate::commands::delete::{DeleteCommand, DeleteCommandImpl};
 use crate::commands::generate::{GenerateCommand, GenerateCommandImpl};
 use crate::commands::list::{ListCommand, ListCommandImpl};
 use crate::commands::setup::{SetupCommand, SetupCommandImpl};
@@ -34,6 +36,13 @@ pub fn run() -> Result<()> {
             let command = SetupCommandImpl::new();
             command.run()?;
         }
+        Mdmg::Delete {
+            template_name,
+            identify,
+        } => {
+            let command = DeleteCommandImpl::new();
+            command.run(template_name, identify)?;
+        }
     };
     Ok(())
 }
